var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { jsx as _jsx } from "react/jsx-runtime";
import { lazy } from 'react';
import initFusion from '@equinor/fusion-framework';
import { FrameworkConfigurator } from '@equinor/fusion-framework';
import { FrameworkProvider } from './context';
import { ModuleProvider } from '@equinor/fusion-framework-react-module';
/**
 * Create a framework provider for react.
 *
 * This function is for providers of framework, like a portal.
 *
 * @param configurator - callback for configuring modules
 * @example
 * ```tsx
 * const config: FrameworkConfigurator = (config) => {}
 * const Portal = () => {
 *   const Framework = createFrameworkProvider(config);
 *   return (
 *      <Suspense fallback={<span>loading...</span>}>
 *          <Framework>{children}</Framework>
 *      </Suspense>
 *   );
 * };
 * ```
 */
export const createFrameworkProvider = (cb, ref) => lazy(() => __awaiter(void 0, void 0, void 0, function* () {
    const configurator = new FrameworkConfigurator();
    yield cb(configurator, ref);
    const framework = yield initFusion(configurator, ref);
    return {
        default: ({ children }) => (_jsx(FrameworkProvider, { value: framework, children: _jsx(ModuleProvider, { value: framework.modules, children: children }) })),
    };
}));
//# sourceMappingURL=create-framework-provider.js.map