import { type IFeatureFlag, type IFeatureFlagProvider } from '@equinor/fusion-framework-module-feature-flag';
export interface UseFeatureResult<T> {
    feature?: IFeatureFlag<T>;
    error?: unknown;
    /**
     * @param enable - Optional provide new enabled state of the feature flag. _Defaults to inversion of current feature flag state_
     */
    toggleFeature: (enable?: boolean) => void;
}
/**
 * Custom hook that retrieves a feature flag from a feature flag provider.
 *
 * @template T - The type of the feature flag value.
 * @param {IFeatureFlagProvider} provider - The feature flag provider.
 * @param {string} key - The key of the feature flag.
 * @returns {UseFeatureResult<T>} - An object containing the feature flag value, a function to toggle the feature flag, and any error that occurred.
 */
export declare const useFeature: <T = unknown>(provider: IFeatureFlagProvider, key: string) => UseFeatureResult<T>;
export default useFeature;
