import { type IFeatureFlagProvider, type IFeatureFlag } from '@equinor/fusion-framework-module-feature-flag';
import { type FeatureSelectorFn } from '@equinor/fusion-framework-module-feature-flag/selectors';
export interface UseFeaturesResult {
    features: IFeatureFlag[];
    error: unknown;
    /**
     * @param key - The key of the feature flag.
     * @param enable - Optional provide new enabled state of the feature flag. _Defaults to inversion of current feature flag state_
     */
    toggleFeature: (key: string, enable?: boolean) => void;
}
/**
 * Custom hook that provides access to the feature flags and their values.
 *
 * @param provider - The feature flag provider.
 * @param selector - Optional function to filter the feature flags.
 * @returns An object containing the features, any error that occurred while retrieving them, and a function to set the enabled state of a feature flag.
 * @throws Error if the feature flag provider is missing.
 */
export declare const useFeatures: (provider?: IFeatureFlagProvider | null, selector?: FeatureSelectorFn) => UseFeaturesResult;
export default useFeatures;
